 /********************************************************************
*   A7159CONFIG.h
*   RF Chip-A7159 Configure Definitions
*
*   This file provides the constants associated with the
*   AMICCOM A7159 device.
*
********************************************************************/
#ifndef _A7159CONFIG_h_
#define _A7159CONFIG_h_

//#define DR_10Kbps_50KIFBW             //915MHz, 10kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
//#define DR_10Kbps_100KIFBW          //915MHz, 10kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
//#define DR_50Kbps_50KIFBW           //915MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
#define DR_100Kbps_100KIFBW         //915MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
//#define DR_150Kbps_150KIFBW         //915MHz, 150kbps (IFBW = 150KHz, Fdev = 56.25KHz), Crystal=19.2MHz
//#define DR_250Kbps_250KIFBW         //915MHz, 250kbps (IFBW = 250KHz, Fdev = 93.75KHz), Crystal=16MHz
//#define DR_50Kbps_50KIFBW_16M       //915MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=16MHz
//#define DR_100Kbps_100KIFBW_16M     //915MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=16MHz
//#define DR_150Kbps_150KIFBW_16M     //915MHz, 150kbps (IFBW = 150KHz, Fdev = 56.25KHz), Crystal=16MHz
//#define DR_2Kbps_50KIFBW            //915MHz, 2kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz


#ifdef DR_10Kbps_50KIFBW

const Uint16 code A7159Config[]=        //915MHz, 10kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x0823,     //SYSTEM CLOCK register,
    0x0A47,     //PLL1 register,
    0x7C05,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0015,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D0,     //RX1 register,     IFBW=50KHz
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 10kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0xF606,     //TX1 register,     Fdev = 18.75kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x8130,     //PM register,      CST=1
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x29C0,     //AGC2 register, 
    0x0045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD981,     //CKO register
    0x0064,     //VCB register,
    0x9247,     //CHG1 register,    910MHz
    0x0E47,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 10kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x0337,		//TX2 register, 	
		0x8200,		//IF1 register, 	Enable Auto-IF, IF=100KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0C00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

const Uint16 code Freq_Cal_Tab[]=
{
    0x0A46, 0x8C05, //903.001MHz
    0x0A47, 0x7C05, //915.001MHz
    0x0A48, 0x6C05  //927.001MHz
};

#endif


#ifdef DR_10Kbps_100KIFBW

const Uint16 code A7159Config[]=        //915MHz, 10kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0x1221,     //SYSTEM CLOCK register,
    0x0A47,     //PLL1 register,
    0x7C05,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0015,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D4,     //RX1 register,     IFBW=100KHz
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 10kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0xF706,     //TX1 register,     Fdev = 37.5kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x8130,     //PM register,      CST=1
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x29C0,     //AGC2 register, 
    0x0045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD981,     //CKO register
    0x0064,     //VCB register,
    0x9247,     //CHG1 register,    910MHz
    0x0E47,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 10kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0x0337,		//TX2 register, 	
		0x8400,		//IF1 register, 	Enable Auto-IF, IF=200KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0C00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

const Uint16 code Freq_Cal_Tab[]=
{
    0x0A46, 0x8C05, //903.001MHz
    0x0A47, 0x7C05, //915.001MHz
    0x0A48, 0x6C05  //927.001MHz
};

#endif


#ifdef DR_50Kbps_50KIFBW

const Uint16 code A7159Config[]=        //915MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x0023,     //SYSTEM CLOCK register,
    0x0A47,     //PLL1 register,
    0x7C05,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0015,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D0,     //RX1 register,     IFBW=50KHz
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0xF606,     //TX1 register,     Fdev = 18.75kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x0130,     //PM register,
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x29C0,     //AGC2 register, 
    0x0045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD981,     //CKO register
    0x0064,     //VCB register,
    0x9247,     //CHG1 register,    910MHz
    0x0E47,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x0337,		//TX2 register, 	
		0x8200,		//IF1 register, 	Enable Auto-IF, IF=100KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0C00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

const Uint16 code Freq_Cal_Tab[]=
{
    0x0A46, 0x8C05, //903.001MHz
    0x0A47, 0x7C05, //915.001MHz
    0x0A48, 0x6C05  //927.001MHz
};

#endif


#ifdef DR_100Kbps_100KIFBW

const Uint16 code A7159Config[]=        //915MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0x0021,     //SYSTEM CLOCK register,
    0x0A47,     //PLL1 register,
    0x7C05,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0015,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D4,     //RX1 register,     IFBW=100KHz 
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0xF706,     //TX1 register,     Fdev = 37.5kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x0130,     //PM register,
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x29C0,     //AGC2 register, 
    0x0045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD981,     //CKO register
    0x0064,     //VCB register,
    0x9247,     //CHG1 register,    910MHz
    0x0E47,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=12.8MHz
{
    0x0337,		//TX2 register, 	
		0x8400,		//IF1 register, 	Enable Auto-IF, IF=200KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0C00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

const Uint16 code Freq_Cal_Tab[]=
{
    0x0A46, 0x8C05, //903.001MHz
    0x0A47, 0x7C05, //915.001MHz
    0x0A48, 0x6C05  //927.001MHz
};

#endif



#ifdef DR_150Kbps_150KIFBW

const Uint16 code A7159Config[]=        //915MHz, 150kbps (IFBW = 150KHz, Fdev = 56.25KHz), Crystal=19.2MHz
{
    0x0021,     //SYSTEM CLOCK register,
    0x0A2F,     //PLL1 register,
    0xA803,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0015,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D8,     //RX1 register,     IFBW=150KHz 
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 150kbps (IFBW = 150KHz, Fdev = 56.25KHz), Crystal=19.2MHz
{
    0xF706,     //TX1 register,     Fdev = 56.25kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x0130,     //PM register,
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x29C0,     //AGC2 register, 
    0x4045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD981,     //CKO register
    0x0064,     //VCB register,
    0x962F,     //CHG1 register,    910MHz
    0x0030,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 150kbps (IFBW = 150KHz, Fdev = 56.25KHz), Crystal=19.2MHz
{
    0x8337,		//TX2 register, 	
		0x8400,		//IF1 register, 	Enable Auto-IF, IF=300KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0C00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

const Uint16 code Freq_Cal_Tab[]=
{
    0x0A2F, 0x0803, //903.001MHz
    0x0A2F, 0xA803, //915.001MHz
    0x0A30, 0x4803  //927.001MHz
};

#endif


#ifdef DR_250Kbps_250KIFBW

const Uint16 code A7159Config[]=        //915MHz, 250kbps (IFBW = 250KHz, Fdev = 93.75KHz), Crystal=16MHz
{
    0x0020,     //SYSTEM CLOCK register,
    0x0A39,     //PLL1 register,
    0x3004,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0015,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18DC,     //RX1 register,     IFBW=250KHz 
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 250kbps (IFBW = 250KHz, Fdev = 93.75KHz), Crystal=16MHz
{
    0xF70C,     //TX1 register,     Fdev = 93.75kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x0130,     //PM register,
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x69C0,     //AGC2 register, 
    0x8045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD981,     //CKO register
    0x00E4,     //VCB register,
    0x9E38,     //CHG1 register,    910MHz
    0x0839,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 250kbps (IFBW = 250KHz, Fdev = 93.75KHz), Crystal=16MHz
{
    0x0337,		//TX2 register, 	
		0x8800,		//IF1 register, 	Enable Auto-IF, IF=500KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0E00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

const Uint16 code Freq_Cal_Tab[]=
{
    0x0A38, 0x7004, //903.001MHz
    0x0A39, 0x3004, //915.001MHz
    0x0A39, 0xF004  //927.001MHz
};

#endif


#ifdef DR_50Kbps_50KIFBW_16M

const Uint16 code A7159Config[]=        //915MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=16MHz
{
    0x00FC,     //SYSTEM CLOCK register,
    0x0A39,     //PLL1 register,
    0x3004,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0015,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D0,     //RX1 register,     IFBW=50KHz
    0x701D,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=16MHz
{
    0xF413,     //TX1 register,     Fdev = 18.75kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x0130,     //PM register,
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x29C0,     //AGC2 register, 
    0x8045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD183,     //CKO register
    0x0064,     //VCB register,
    0x9E38,     //CHG1 register,    910MHz
    0x0839,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 50kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=16MHz
{
    0x0337,		//TX2 register, 	
		0x8199,		//IF1 register, 	Enable Auto-IF, IF=100KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0C00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

#endif


#ifdef DR_100Kbps_100KIFBW_16M

const Uint16 code A7159Config[]=        //915MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=16MHz
{
    0x00FC,     //SYSTEM CLOCK register,
    0x0A39,     //PLL1 register,
    0x3004,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0015,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x1894,     //RX1 register,     IFBW=100KHz 
    0x701D,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=16MHz
{
    0xF34D,     //TX1 register,     Fdev = 37.5kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x0130,     //PM register,
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x29C0,     //AGC2 register, 
    0x8045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD183,     //CKO register
    0x0064,     //VCB register,
    0x9E38,     //CHG1 register,    910MHz
    0x0839,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 100kbps (IFBW = 100KHz, Fdev = 37.5KHz), Crystal=16MHz
{
    0x0337,		//TX2 register, 	
		0x8333,		//IF1 register, 	Enable Auto-IF, IF=200KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0C00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

#endif



#ifdef DR_150Kbps_150KIFBW_16M

const Uint16 code A7159Config[]=        //915MHz, 150kbps (IFBW = 150KHz, Fdev = 56.25KHz), Crystal=19.2MHz
{
    0x00FC,     //SYSTEM CLOCK register,
    0x0A39,     //PLL1 register,
    0x3004,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0017,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x1898,     //RX1 register,     IFBW=150KHz 
    0x701D,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 150kbps (IFBW = 150KHz, Fdev = 56.25KHz), Crystal=19.2MHz
{
    0xF373,     //TX1 register,     Fdev = 56.25kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x0130,     //PM register,
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x29C0,     //AGC2 register, 
    0xC045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD183,     //CKO register
    0x0064,     //VCB register,
    0x9E38,     //CHG1 register,    910MHz
    0x0839,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 150kbps (IFBW = 150KHz, Fdev = 56.25KHz), Crystal=19.2MHz
{
    0x8337,		//TX2 register, 	
		0x84CC,		//IF1 register, 	Enable Auto-IF, IF=300KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0C00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

#endif


#ifdef DR_2Kbps_50KIFBW

const Uint16 code A7159Config[]=        //915MHz, 2kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x3023,     //SYSTEM CLOCK register,
    0x0A47,     //PLL1 register,
    0x7C05,     //PLL2 register,    915.001MHz
    0x0000,     //PLL3 register,
    0x1A20,     //PLL4 register,
    0x0024,     //PLL5 register,
    0x0000,     //PLL6 register,
    0x0015,     //CRYSTAL register,
    0x0000,     //PAGEA,
    0x0000,     //PAGEB,
    0x18D0,     //RX1 register,     IFBW=50KHz
    0x7009,     //RX2 register,     by preamble
    0x4000,     //ADC register,     
    0x0800,     //PIN CONTROL register,     Use Strobe CMD
    0x4C45,     //CALIBRATION register,
    0x20C0      //MODE CONTROL register,    Use FIFO mode
};

const Uint16 code A7159Config_PageA[]=   //915MHz, 2kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0xF606,     //TX1 register,     Fdev = 18.75kHz
    0x0000,     //WOR1 register,
    0xF800,     //WOR2 register,
    0x1107,     //RFI register,     Enable Tx Ramp up/down  
    0x8130,     //PM register,      CST=1
    0x0402,     //RTH register,
    0x400F,     //AGC1 register,    
    0x29C0,     //AGC2 register, 
    0x0045,     //GIO register,     GIO2=WTR, GIO1=FSYNC
    0xD981,     //CKO register
    0x0064,     //VCB register,
    0x9247,     //CHG1 register,    910MHz
    0x0E47,     //CHG2 register,    920MHz
    0x003F,     //FIFO register,    FEP=63+1=64bytes
    0x1507,     //CODE register,    Preamble=4bytes, ID=4bytes
    0x8000      //WCAL register,
};

const Uint16 code A7159Config_PageB[]=   //915MHz, 2kbps (IFBW = 50KHz, Fdev = 18.75KHz), Crystal=12.8MHz
{
    0x0337,		//TX2 register, 	
		0x8200,		//IF1 register, 	Enable Auto-IF, IF=100KHz
		0x0000,		//IF2 register,
		0x0000,		//ACK register,
		0x0000,		//ART register,
		0x0000,		//SYN register,
		0x0000,		//ACKFIFO register,
		0x0000,		//DSSS register,
		0x0000,		//CCM1 register,
		0x0000,		//CCM2 register,
		0x0000,		//CCM3 register,
		0x0000,		//CCM4 register,
		0x0000,		//CCM5 register,
		0x0000,		//RF_Cmd register,
		0x0000,		//Btn_Cmd register,
		0x0000,		//DSSS2 register,
		0x0000,		//DSSS3 register,
		0x0000,		//CCM6 register,
		0x0C00,		//CDET register,
		0x0000,		//DC_SHIFT register,
		0x0000		//RCOSC register,
};

const Uint16 code Freq_Cal_Tab[]=
{
    0x0A46, 0x8C05, //903.001MHz
    0x0A47, 0x7C05, //915.001MHz
    0x0A48, 0x6C05  //927.001MHz
};

#endif


#endif