/*********************************************************************
**  Device:     A7159
**  File:       main.c
**  Target:     Winbond W77LE58
**  Tools:      ICE
**  Updated:    2017-03-20
**  Description:
**  This file is a sample code for your reference.
**
**  Copyright (C) 2017 AMICCOM Corp.
**
*********************************************************************/
#include "../include/define.h"
#include "../include/A9108.h"
#include "../include/A7159reg.h"
#include "../include/A7159config.h"
#include "../include/Uti.h"

/*********************************************************************
**  I/O Declaration
*********************************************************************/
#define SCS         P0_0        //SPI SCS
#define SCK         P0_1        //SPI SCK
#define SDIO        P0_2        //SPI SDIO
#define CKO         P0_3        //CKO
#define GIO1        P0_5        //GIO1
#define GIO2        P0_6        //GIO2

/*********************************************************************
**  Constant Declaration
*********************************************************************/
#define TIMEOUT     100         //100ms
#define t0hrel      1000        //1ms

/*********************************************************************
**  Global Variable Declaration
*********************************************************************/
Uint8   data    timer;
Uint8   data    TimeoutFlag;
Uint16  idata   RxCnt;
Uint32  idata   Err_ByteCnt;
Uint32  idata   Err_BitCnt;
Uint16  idata   TimerCnt0;
Uint8   data    *Uartptr;
Uint8   data    UartSendCnt;
Uint8   data    CmdBuf[11];
Uint8   xdata   tmpbuf[256];
Uint8	data	fb;
Uint16	data	BODF;

const Uint8 code BitCount_Tab[16]={0,1,1,2,1,2,2,3,1,2,2,3,2,3,3,4};
const Uint8 code ID_Tab[8]={0x34,0x75,0xC5,0x8C,0xC7,0x33,0x45,0xE7};   //ID code
const Uint8 code PN9_Tab[]=
{   
	0xFF, 0x83, 0xDF, 0x17, 0x32, 0x09, 0x4E, 0xD1,
	0xE7, 0xCD, 0x8A, 0x91, 0xC6, 0xD5, 0xC4, 0xC4,
	0x40, 0x21, 0x18, 0x4E, 0x55, 0x86, 0xF4, 0xDC,
	0x8A, 0x15, 0xA7, 0xEC, 0x92, 0xDF, 0x93, 0x53,
	0x30, 0x18, 0xCA, 0x34, 0xBF, 0xA2, 0xC7, 0x59,
	0x67, 0x8F, 0xBA, 0x0D, 0x6D, 0xD8, 0x2D, 0x7D,
	0x54, 0x0A, 0x57, 0x97, 0x70, 0x39, 0xD2, 0x7A,
	0xEA, 0x24, 0x33, 0x85, 0xED, 0x9A, 0x1D, 0xE0
};	// This table are 64bytes PN9 pseudo random code(MSB->LSB).

const Uint8 code PN9_Tab_LSB[]=
{	
	0xFF, 0xC1, 0xFB, 0xE8, 0x4C, 0x90, 0x72, 0x8B,
	0xE7, 0xB3, 0x51, 0x89, 0x63, 0xAB, 0x23, 0x23,
	0x02, 0x84, 0x18, 0x72, 0xAA, 0x61, 0x2F, 0x3B,
	0x51, 0xA8, 0xE5, 0x37, 0x49, 0xFB, 0xC9, 0xCA,
	0x0C, 0x18, 0x53, 0x2C, 0xFD, 0x45, 0xE3, 0x9A,
	0xE6, 0xF1, 0x5D, 0xB0, 0xB6, 0x1B, 0xB4, 0xBE,
	0x2A, 0x50, 0xEA, 0xE9, 0x0E, 0x9C, 0x4B, 0x5E,
	0x57, 0x24, 0xCC, 0xA1, 0xB7, 0x59, 0xB8, 0x07
};	// This table are 64bytes PN9 pseudo random code(LSB->MSB).

/*********************************************************************
**  function Declaration
*********************************************************************/
void Timer0ISR(void);
void UART0Isr(void);
void InitTimer0(void);
void InitUART0(void);
Uint8 InitRF(void);
Uint8 A7159_Config(void);
Uint8 A7159_WriteID(void);
Uint8 A7159_Cal(void);
void StrobeCMD(Uint8);
void ByteSend(Uint8);
Uint8 ByteRead(void);
void A7159_WriteReg(Uint8, Uint16);
Uint16 A7159_ReadReg(Uint8);
void A7159_WritePageA(Uint8, Uint16);
Uint16 A7159_ReadPageA(Uint8);
void A7159_WritePageB(Uint8, Uint16);
Uint16 A7159_ReadPageB(Uint8);
void A7159_WriteFIFO(void);
void RxPacket(void);
void Err_State(void);
void entry_deep_sleep_mode(void);
void wake_up_from_deep_sleep_mode(void);
Uint8 BODF_Detect(void);
void DSSS_MODE(void);

/*********************************************************************
* main loop
*********************************************************************/

/*Frequency setting description.*/
//User can choose frequency in ''A7159CONFIG.h''
void main(void)
{
	Uint16 i;

    //initHW
    P0 = 0xFF;
    P1 = 0xFF;
    P3 = 0xFF;
	
		P0OE=0xFF;
		P1OE=0xFF;
		P3OE=0xFF;

    InitTimer0();
    InitUART0();
    TR0=1;  //Timer0 on
    EA=1;   //enable interrupt
    
    Delay10ms(1);   //for regulator settling time (power on only)

    while(1)
    {
        if(InitRF()) //init RF
        {
            entry_deep_sleep_mode();
            Delay1ms(2);
            wake_up_from_deep_sleep_mode();
        }
        else
        {
            break;
        }
    }
	/*modify Frequency.*/

	//Step1.Using EK UI tool. 
	//Step2.Load config.(Must choose the same config as A7159CONFIG.h)
	//Step3.modify the RF Frequency in Frequency Setup.
	//Step4.Look at PLL1 and PLL2 register.

	/*Ex:Load (915MHz 100kbps IFBW = 100KHz Fdev = 37.5KHz Crystal=12.8MHz)->modify the RF Frequency(915.001)->Look at PLL1 and PLL2 register
	A7159_WriteReg(PLL1_REG, 0x0A47);
	A7159_WriteReg(PLL2_REG, 0x7C05);
	*/
	
	DSSS_MODE();
	
	A7159_WritePageA(FIFO_PAGEA,0xC0FF); //FEP=255+1=256bytes  FPM[1:0]=11 
	A7159_WritePageA(CKO_PAGEA,0xD993);  //CKO = FPF
	
    if((P3 & 0x04)==0x04)   //if P3.2=1, master
    {
        while(1)
      {
            if(BODF_Detect())
				break;
//========================================================================
			StrobeCMD(CMD_TFR);     //TX FIFO address pointer reset
			SCS=0;
			ByteSend(CMD_FIFO_W);   //TX FIFO write command
			for(i=0; i <64; i++)
			ByteSend(i);
			SCS=1;
//=====================================			
      StrobeCMD(CMD_TX);          
			while(CKO==0);		//wait FPF go high
			SCS=0;
			ByteSend(CMD_FIFO_W);
			for(i=64;i<112;i++)
			{
				ByteSend(i);
			}
			SCS=1;
//=========================================		
			while(CKO==0);		//wait FPF go high
			SCS=0;
			ByteSend(CMD_FIFO_W);
			for(i=112;i<160;i++)
			{
				ByteSend(i);
			}
			SCS=1;
//=========================================		
			while(CKO==0);		//wait FPF go high
			SCS=0;
			ByteSend(CMD_FIFO_W);
			for(i=160;i<208;i++)
			{
				ByteSend(i);
			}
			SCS=1;
//=========================================			
			while(CKO==0);		//wait FPF go high
			SCS=0;
			ByteSend(CMD_FIFO_W);
			for(i=208;i<256;i++)
			{
				ByteSend(i);
			}
			SCS=1;			
      while(GIO2);        //wait transmit completed
			Delay10us(1);
      }
    }
    else    //if P3.2=0, slave
    {
        RxCnt = 0;
        Err_ByteCnt = 0;
        Err_BitCnt = 0;

        while(1)
        {
            if(BODF_Detect())
				break;

			StrobeCMD(CMD_RX);
			
			while(CKO==0);		//wait FPF go high
			SCS=0;
			ByteSend(CMD_FIFO_R); //address 0x05, bit cmd=0, r/w=1
			for(i=0;i<48;i++)
				tmpbuf[i]=ByteRead();
			SCS=1;

			while(CKO==0);		//wait FPF go high
			SCS=0;
			ByteSend(CMD_FIFO_R); //address 0x05, bit cmd=0, r/w=1
			for(i=48;i<96;i++)
				tmpbuf[i]=ByteRead();
			SCS=1;
			
			while(CKO==0);		//wait FPF go high
			SCS=0;
			ByteSend(CMD_FIFO_R); //address 0x05, bit cmd=0, r/w=1
			for(i=96;i<144;i++)
				tmpbuf[i]=ByteRead();
			SCS=1;
			
			while(CKO==0);		//wait FPF go high
			SCS=0;
			ByteSend(CMD_FIFO_R); //address 0x05, bit cmd=0, r/w=1
			for(i=144;i<192;i++)
				tmpbuf[i]=ByteRead();
			SCS=1;
			
			while(CKO==0);		//wait FPF go high
			SCS=0;
			ByteSend(CMD_FIFO_R); //address 0x05, bit cmd=0, r/w=1
			for(i=192;i<240;i++)
				tmpbuf[i]=ByteRead();
			SCS=1;
			
            while(GIO2);        //wait receive completed
			
			SCS=0;
			ByteSend(CMD_FIFO_R); //address 0x05, bit cmd=0, r/w=1
			for(i=240;i<256;i++)
				tmpbuf[i]=ByteRead();
			SCS=1;

        }
    }
}

/************************************************************************
**  Timer0ISR
************************************************************************/
void Timer0ISR(void) interrupt 1
{
    TH0 = (65536-t0hrel)>>8;    //Reload Timer0 high byte, low byte
    TL0 = 65536-t0hrel;

    timer++;
    if(timer >= TIMEOUT)
    {
        TimeoutFlag=1;
    }

    TimerCnt0++;
    if(TimerCnt0 == 500)
    {
        TimerCnt0=0;
        CmdBuf[0]=0xF1;

        memcpy(&CmdBuf[1], &RxCnt, 2);
        memcpy(&CmdBuf[3], &Err_ByteCnt, 4);
        memcpy(&CmdBuf[7], &Err_BitCnt, 4);

        UartSendCnt=11;
        Uartptr=&CmdBuf[0];
        SBUF=CmdBuf[0];
    }
}

/************************************************************************
**  UART0ISR
************************************************************************/
void UART0Isr(void) interrupt 4 using 3
{
    if(TI==1)
    {
        TI=0;
        UartSendCnt--;
        if(UartSendCnt !=0)
        {
            Uartptr++;
            SBUF = *Uartptr;
        }
    }
}

/************************************************************************
**  init Timer0
************************************************************************/
void InitTimer0(void)
{
    TR0 = 0;
    TMOD=(TMOD & 0xF0)|0x01;    //Timer0 mode=1
    TH0 = (65536-t0hrel)>>8;    //setup Timer0 high byte, low byte
    TL0 = 65536-t0hrel;
    TF0 = 0;                    //Clear any pending Timer0 interrupts
    ET0 = 1;                    //Enable Timer0 interrupt
}

/************************************************************************
**  Init UART0
************************************************************************/
void InitUART0(void)
{
    TH1 = 0xFD;                 //BaudRate 9600;
    TL1 = 0xFD;
    SCON= 0x40;
    TMOD= (TMOD & 0x0F) | 0x20;
    REN = 1;
    TR1 = 1;
    ES  = 1;
}

/*********************************************************************
** Strobe Command
*********************************************************************/
void StrobeCMD(Uint8 cmd)
{
    Uint8 i;

    SCS=0;
    for(i=0; i<8; i++)
    {
        if(cmd & 0x80)
            SDIO = 1;
        else
            SDIO = 0;

        _nop_();
        SCK=1;
        _nop_();
        SCK=0;
        cmd<<=1;
    }
    SCS=1;
}

/************************************************************************
**  ByteSend
************************************************************************/
void ByteSend(Uint8 src)
{
    Uint8 i;

    for(i=0; i<8; i++)
    {
        if(src & 0x80)
            SDIO = 1;
        else
            SDIO = 0;

        _nop_();
        SCK=1;
        _nop_();
        SCK=0;
        src<<=1;
    }
}

/************************************************************************
**  ByteRead
************************************************************************/
Uint8 ByteRead(void)
{
    Uint8 i,tmp;

    //read data code
    SDIO=1;     //SDIO pull high
    for(i=0; i<8; i++)
    {
        if(SDIO)
            tmp = (tmp << 1) | 0x01;
        else
            tmp = tmp << 1;

        SCK=1;
        _nop_(); 
        SCK=0;
        _nop_();
    }
    return tmp;
}

/************************************************************************
**  A7159_WriteReg
************************************************************************/
void A7159_WriteReg(Uint8 address, Uint16 dataWord)
{
    Uint8 i;

    SCS=0;
    address |= CMD_Reg_W;
    for(i=0; i<8; i++)
    {
        if(address & 0x80)
            SDIO = 1;
        else
            SDIO = 0;
		
		_nop_();
        SCK=1;
        _nop_(); 
        SCK=0;
        address<<=1;
    }
    _nop_();

    //send data word
    for(i=0; i<16; i++)
    {
        if(dataWord & 0x8000)
            SDIO = 1;
        else
            SDIO = 0;

		_nop_();
        SCK=1;
        _nop_();
        SCK=0;
        dataWord<<=1;
    }
    SCS=1;
}

/************************************************************************
**  A7159_ReadReg
************************************************************************/
Uint16 A7159_ReadReg(Uint8 address)
{
    Uint8 i;
    Uint16 tmp;

    SCS=0;
    address |= CMD_Reg_R;
    for(i=0; i<8; i++)
    {
        if(address & 0x80)
            SDIO = 1;
        else
            SDIO = 0;

        _nop_(); 
        SCK=1;
        _nop_();
        SCK=0;
        address<<=1;
    }
    _nop_();
    
    //read data code
    SDIO=1;     //SDIO pull high
    for(i=0; i<16; i++)
    {
        if(SDIO)
            tmp = (tmp << 1) | 0x01;
        else
            tmp = tmp << 1;

        SCK=1;
        _nop_();
        SCK=0;
        _nop_();
    }
    SCS=1;
    return tmp;
}

/************************************************************************
**  A7159_WritePageA
************************************************************************/
void A7159_WritePageA(Uint8 address, Uint16 dataWord)
{
    Uint16 tmp;

    tmp = address;
    tmp = ((tmp << 12) | A7159Config[CRYSTAL_REG]);
    A7159_WriteReg(CRYSTAL_REG, tmp);
    A7159_WriteReg(PAGEA_REG, dataWord);
}

/************************************************************************
**  A7159_ReadPageA
************************************************************************/
Uint16 A7159_ReadPageA(Uint8 address)
{
    Uint16 tmp;

    tmp = address;
    tmp = ((tmp << 12) | A7159Config[CRYSTAL_REG]);
    A7159_WriteReg(CRYSTAL_REG, tmp);
    tmp = A7159_ReadReg(PAGEA_REG);
    return tmp;
}

/************************************************************************
**  A7159_WritePageB
************************************************************************/
void A7159_WritePageB(Uint8 address, Uint16 dataWord)
{
    Uint16 tmp;

    tmp = address;
    tmp = ((tmp << 7) | A7159Config[CRYSTAL_REG]);
    A7159_WriteReg(CRYSTAL_REG, tmp);
    A7159_WriteReg(PAGEB_REG, dataWord);
}

/************************************************************************
**  A7159_ReadPageB
************************************************************************/
Uint16 A7159_ReadPageB(Uint8 address)
{
    Uint16 tmp;

    tmp = address;
    tmp = ((tmp << 7) | A7159Config[CRYSTAL_REG]);
    A7159_WriteReg(CRYSTAL_REG, tmp);
    tmp = A7159_ReadReg(PAGEB_REG);
    return tmp;
}

/*********************************************************************
** InitRF
*********************************************************************/
Uint8 InitRF(void)
{
    //initial pin
    SCS = 1;
    SCK = 0;
    SDIO= 1;
    CKO = 1;
    GIO1= 1;
    GIO2= 1;

    Delay1ms(1);            //delay 1ms for regulator stabilized
    StrobeCMD(CMD_RF_RST);  //reset A7159 chip
    Delay1ms(1);
    
    if(A7159_Config())      //config A7159 chip
        return 1;

    Delay100us(8);          //delay 800us for crystal stabilized

    if(A7159_WriteID())     //write ID code
        return 1;

    if(A7159_Cal())         //IF and VCO Calibration
        return 1;

    return 0;
}

/*********************************************************************
** A7159_Config
*********************************************************************/
Uint8 A7159_Config(void)
{
    Uint8 i;
    Uint16 tmp;

    for(i=0; i<8; i++)
        A7159_WriteReg(i, A7159Config[i]);

    for(i=10; i<16; i++)
  			A7159_WriteReg(i, A7159Config[i]);

    for(i=0; i<16; i++)
        A7159_WritePageA(i, A7159Config_PageA[i]);

    for(i=0; i<21; i++)
        A7159_WritePageB(i, A7159Config_PageB[i]);

    //for check        
    tmp = A7159_ReadReg(SYSTEMCLOCK_REG);
    if(tmp != A7159Config[SYSTEMCLOCK_REG])
    {
        return 1;   
    }
    
    return 0;
}

/************************************************************************
**  WriteID
************************************************************************/
Uint8 A7159_WriteID(void)
{
    Uint8 i;
    Uint8 d1, d2, d3, d4;

    SCS=0;
    ByteSend(CMD_ID_W);
    for(i=0; i<4; i++)
        ByteSend(ID_Tab[i]);
    SCS=1;

    SCS=0;
    ByteSend(CMD_ID_R);
    d1=ByteRead();
    d2=ByteRead();
    d3=ByteRead();
    d4=ByteRead();
    SCS=1;
    
    if((d1!=ID_Tab[0]) || (d2!=ID_Tab[1]) || (d3!=ID_Tab[2]) || (d4!=ID_Tab[3]))
    {
        return 1;
    }
    
    return 0;
}

/*********************************************************************
** A7159_Cal
*********************************************************************/
Uint8 A7159_Cal(void)
{
    Uint8 i,fb_ok;
    Uint8 fb_old, fcd, fbcf;//IF Filter
    Uint8 vb,vbcf;          //VCO Current
    Uint8 vcb, vccf;        //VCO Band
    Uint16 tmp;
    bit fb_fail;
    
    StrobeCMD(CMD_STBY);

    //IF calibration procedure @STB state
	 fb_fail=0;
	
	 for(i=0;i<3;i++)
	 {
      A7159_WriteReg(MODE_REG, A7159Config[MODE_REG] | 0x0802);       //IF Filter & VCO Current Calibration
      do{
         tmp = A7159_ReadReg(MODE_REG);
      }while(tmp & 0x0802);
    
      //for check(IF Filter)
      tmp = A7159_ReadReg(CALIBRATION_REG);
      fb = tmp & 0x0F;
      fcd = (tmp>>11) & 0x1F;
      fbcf = (tmp>>4) & 0x01;
    
	  if((fb<3) || (fb>11))
		fb_fail = 1;
	  else
      {		  
	    if(i==0)
		 fb_old = fb;
	    else
		{	
		 if(fb != fb_old)
		 {
       if(fb > fb_old)
			 {
         if((fb-fb_old)!=1)
          fb_fail = 1;
       }     
       else
       {
         if((fb_old-fb)!=1)
          fb_fail = 1;
       } 
      }
	   }
	  }
	  
	  if((fbcf) || (fb_fail) || (fcd>6))
      {
        return 1;
      }
	 }

    //for check(VCO Current)
    tmp = A7159_ReadPageA(VCB_PAGEA);
    vcb = tmp & 0x0F;
    vccf = (tmp>>4) & 0x01;
    if(vccf)
    {
        return 1;
    }
    
    
    //RSSI Calibration procedure @STB state
    A7159_WriteReg(ADC_REG, 0x4C00);                                //set ADC average=64
    A7159_WriteReg(MODE_REG, A7159Config[MODE_REG] | 0x1000);       //RSSI Calibration
    do{
        tmp = A7159_ReadReg(MODE_REG);
    }while(tmp & 0x1000);
    A7159_WriteReg(ADC_REG, A7159Config[ADC_REG]);


    //VCO calibration procedure @STB state
    for(i=0; i<3; i++)
    {
        A7159_WriteReg(PLL1_REG, Freq_Cal_Tab[i*2]);
        A7159_WriteReg(PLL2_REG, Freq_Cal_Tab[i*2+1]);
        A7159_WriteReg(MODE_REG, A7159Config[MODE_REG] | 0x0004);   //VCO Band Calibration
        do{
            tmp = A7159_ReadReg(MODE_REG);
        }while(tmp & 0x0004);
    
        //for check(VCO Band)
        tmp = A7159_ReadReg(CALIBRATION_REG);
        vb = (tmp >>5) & 0x07;
        vbcf = (tmp >>8) & 0x01;
        if(vbcf)
        {
            return 1;
        }
    }
    
	fb_ok = 1;
    return 0;
}

/*********************************************************************
** A7159_WriteFIFO
*********************************************************************/
void A7159_WriteFIFO(void)
{
    Uint8 i;

    StrobeCMD(CMD_TFR);     //TX FIFO address pointer reset

    SCS=0;
    ByteSend(CMD_FIFO_W);   //TX FIFO write command
    for(i=0; i <64; i++)
        ByteSend(PN9_Tab[i]);
    SCS=1;
}

/*********************************************************************
** RxPacket
*********************************************************************/
void RxPacket(void)
{
    Uint8 i;
    Uint8 recv;
    Uint8 tmp;

    RxCnt++;

    StrobeCMD(CMD_RFR);     //RX FIFO address pointer reset

    SCS=0;
    ByteSend(CMD_FIFO_R);   //RX FIFO read command
    for(i=0; i <64; i++)
    {
        tmpbuf[i] = ByteRead();
    }
    SCS=1;

    for(i=0; i<64; i++)
    {
        recv = tmpbuf[i];
        tmp = recv ^ PN9_Tab[i];
        if(tmp!=0)
        {
            Err_ByteCnt++;
            Err_BitCnt += (BitCount_Tab[tmp>>4] + BitCount_Tab[tmp & 0x0F]);
        }
    }
}

/*********************************************************************
** Err_State
*********************************************************************/
void Err_State(void)
{
    //ERR display
    //Error Proc...
    //...
    while(1);
}

/*********************************************************************
** entry_deep_sleep_mode
*********************************************************************/
void entry_deep_sleep_mode(void)
{
    StrobeCMD(CMD_RF_RST);              //RF reset
    A7159_WriteReg(PIN_REG, A7159Config[PIN_REG] | 0x0800);             //SCMDS=1
    A7159_WritePageA(PM_PAGEA, A7159Config_PageA[PM_PAGEA] | 0x0010);   //QDS=1
	A7159_WritePageA(WCAL_PAGEA, A7159Config_PageA[WCAL_PAGEA] & 0x7FFF | 0x4000);   //ENDV=0, QDSD=1
    StrobeCMD(CMD_SLEEP);               //entry sleep mode
    Delay100us(6);                      //delay 600us for VDD_A shutdown, C load=0.1uF
    StrobeCMD(CMD_DEEP_SLEEP);          //entry deep sleep mode
    Delay100us(2);                      //delay 200us for VDD_D shutdown, C load=0.1uF
}

/*********************************************************************
** wake_up_from_deep_sleep_mode
*********************************************************************/
void wake_up_from_deep_sleep_mode(void)
{
    StrobeCMD(CMD_STBY);    //wake up
    Delay1ms(2);            //delay 2ms for VDD_D stabilized
    //InitRF();
}

/*********************************************************************
** BODF_Detect
*********************************************************************/
Uint8 BODF_Detect(void)
{
    Uint16 tmp;
	  tmp = A7159_ReadPageA(WOR1_PAGEA);    
    BODF = ((tmp>>11) & 0x01);

    if(BODF)
    {
        return 1;
    } 

    return 0;
}

/*********************************************************************
** DSSS_MODE
*********************************************************************/
void DSSS_MODE(void)
{
	A7159_WritePageA(CODE_PAGEA, 0x1506);	//PML=3bytes, IDL=2bytes
	//DSSS mode : Preamble Length=3bytes
	//IDL[1:0]=[x0], x=don't care, ID Length=1byte
	//IDL[1:0]=[x1], x=don't care, ID Length=2bytes
	
	A7159_WritePageB(DC_SHIFT_PAGEB, A7159Config_PageB[DC_SHIFT_PAGEB] | 0x0400);	//DSSS mode : Preamble detect=2bytes
	A7159_WritePageB(DSSS_PAGEB, A7159Config_PageB[DSSS_PAGEB] | 0xC4FF);	//DSSS setting : ETHM=3, DSSS_SEL=1, FSYNC_D=255
	A7159_WritePageB(DSSS2_PAGEB, A7159Config_PageB[DSSS2_PAGEB] | 0x6200);	//TCNT_SEL=1, TCNT=34
	A7159_WritePageB(SYN_PAGEB, A7159Config_PageB[SYN_PAGEB] | 0x0400);		//enable DSSS=1
}